# Code: Sangdon Lim

rstudioapi::restartSession()

library(PROsetta)
library(mirt)
library(mvnfast)
library(stringr)
library(devEMF)

d_original <- loadData(
  response  = "dat_dePHQ9_original.csv",
  itemmap   = "imap_dePHQ9.csv",
  anchor    = "anchor_dePHQ9.csv",
  input_dir = "data"
)
d_validation <- loadData(
  response  = "dat_dePHQ9_validation.csv",
  itemmap   = "imap_dePHQ9.csv",
  anchor    = "anchor_dePHQ9.csv",
  input_dir = "data"
)

# Figure 3

set.seed(1)
ipar_original   <- runCalibration(d_original, fixedpar = TRUE)
set.seed(1)
ipar_validation <- runCalibration(d_validation, fixedpar = TRUE)

for (img_format in c("eps", "emf", "svg")) {

  setEPS()
  if (img_format == "eps") postscript("figures/Figure 3.eps", width = 9, height = 4.5)
  if (img_format == "emf") emf(file = "figures/Figure 3.emf", width = 9, height = 4.5)
  if (img_format == "svg") svg(file = "figures/Figure 3.svg", width = 9, height = 4.5)

  theta_grid <- seq(-4, 4, .1)

  scores_original   <- theta_grid * 0
  scores_validation <- theta_grid * 0

  for (phq_item in getItemNames(d_original, 2)) {

    item_original   <- extract.item(ipar_original  , phq_item)
    item_validation <- extract.item(ipar_validation, phq_item)
    scores_original   <- scores_original   + expected.item(item_original  , theta_grid)
    scores_validation <- scores_validation + expected.item(item_validation, theta_grid)

  }

  par(mfrow = c(1, 2), mar = c(5, 4, 4, 4) + .1)

  # Test score
  plot(
    0, 0, type = "n",
    xlim = range(theta_grid), ylim = c(0, 27),
    xlab = "Theta", ylab = "Expected Test Score",
    axes = F)

  axis(1)
  axis(2, at = c(seq(0, 27, 5), 27))

  lines(theta_grid, scores_original  , col = "blue")
  lines(theta_grid, scores_validation, col = "red", lty = 2)

  legend(
    "topleft",
    c("Original", "Validation"),
    col = c("blue", "red"),
    lty = c(1, 2),
    pch = NA,
    inset = c(0.02, 0),
    bty = "n"
  )

  box(lwd = 1)

  # Test information
  plot(
    0, 0, type = "n",
    xlim = range(theta_grid), ylim = c(0, 15),
    xlab = "Theta", ylab = "Test Information",
    axes = F)

  axis(1)
  axis(2, at = seq(0, 15, 5))

  phq_items <- 21:29

  info_original   <- testinfo(ipar_original  , theta_grid, which.items = phq_items)
  info_validation <- testinfo(ipar_validation, theta_grid, which.items = phq_items)

  lines(theta_grid, info_original  , col = "blue")
  lines(theta_grid, info_validation, col = "red", lty = 2)

  par(new = TRUE)
  plot(
    0, 0, type = "n",
    xlim = range(theta_grid), ylim = c(0, 10),
    xlab = "", ylab = "",
    axes = FALSE
  )

  axis(4, at = seq(0, 10, 2))

  theta_grid <- seq(-4, 4, 0.2)
  info_original   <- testinfo(ipar_original  , theta_grid, which.items = phq_items)
  info_validation <- testinfo(ipar_validation, theta_grid, which.items = phq_items)
  SE_original     <- 1 / sqrt(info_original)
  SE_validation   <- 1 / sqrt(info_validation)

  lines(theta_grid, SE_original  , col = "blue")
  lines(theta_grid, SE_validation, col = "red", lty = 2)
  points(theta_grid, SE_original  , col = "blue", bg = "blue", pch = 21, cex = 0.5)
  points(theta_grid, SE_validation, col = "red" , bg = "red" , pch = 21, cex = 0.5)

  legend(
    "topleft",
    c("Information", "Standard Error"),
    col    = "black",
    lty    = 1,
    pch    = c(NA, 21),
    pt.bg  = c(NA, "black"),
    pt.cex = 0.5,
    inset  = c(0.02, 0),
    bty    = "n"
  )

  mtext("Standard Error", side = 4, line = 2)
  box(lwd = 1)

  dev.off()

}
