# Code: Sangdon Lim

rstudioapi::restartSession()

library(PROsetta)
library(mirt)
library(mvnfast)
library(stringr)
library(devEMF)

d_original <- loadData(
  response  = "dat_dePHQ9_original.csv",
  itemmap   = "imap_dePHQ9.csv",
  anchor    = "anchor_dePHQ9.csv",
  input_dir = "data"
)
d_validation <- loadData(
  response  = "dat_dePHQ9_validation.csv",
  itemmap   = "imap_dePHQ9.csv",
  anchor    = "anchor_dePHQ9.csv",
  input_dir = "data"
)

# Figure 4a

set.seed(1)
fp_original   <- runLinking(d_original  , method = "FIXEDPAR")
set.seed(1)
fp_validation <- runLinking(d_validation, method = "FIXEDPAR")

rsss_fp_original   <- runRSSS(d_original  , fp_original  , min_score = 0)
rsss_fp_validation <- runRSSS(d_validation, fp_validation, min_score = 0)

for (img_format in c("eps", "emf", "svg")) {

  setEPS()
  if (img_format == "eps") postscript("figures/Figure 4a.eps", width = 6, height = 6)
  if (img_format == "emf") emf(file = "figures/Figure 4a.emf", width = 6, height = 6)
  if (img_format == "svg") svg(file = "figures/Figure 4a.svg", width = 6, height = 6)

  lhs_scale <- 2
  lhs_raw   <- rsss_fp_original[[lhs_scale]]$raw_2

  # Main plot
  par(mai = c(1, 0.8, 0.1, 0.1) + 0.02)
  par(fig = c(0, 0.8, 0, 0.8))
  plot(0, 0,
    xlab = "Summed Score", ylab = "PROMIS Depression T-score", type = "n",
    xlim = range(lhs_raw), ylim = c(35, 85))
  grid()
  lines(lhs_raw, rsss_fp_original[[lhs_scale]]$tscore  , lty = 1, col = "blue")
  lines(lhs_raw, rsss_fp_validation[[lhs_scale]]$tscore, lty = 2, col = "red")
  legend("topleft",
    c("Original", "Validation"),
    lty = c(1, 2), col = c("blue", "red"),
    bg = "white")
  box()

  # Density (right)
  par(mai = c(1, 0, 0.1, 0.4) + 0.02)
  par(fig = c(0.8, 1, 0, 0.8), new = TRUE)
  plot(
    0, 0, type = "n", axes = F,
    xlim = c(0, 0.04),
    ylim = c(35, 85), xlab = NA, ylab = NA
  )
  # Density from original dataset
  x1 <- getScaleSum(d_original, 2)
  x2 <- rsss_fp_original[[lhs_scale]][, 1:2]
  x  <- merge(x1, x2, by = "raw_2")
  dd <- density(x$tscore)
  lines(dd$y, dd$x, col = "blue")
  # Density from validation dataset
  x1 <- getScaleSum(d_validation, 2)
  x2 <- rsss_fp_validation[[lhs_scale]][, 1:2]
  x  <- merge(x1, x2, by = "raw_2")
  dd <- density(x$tscore)
  lines(dd$y, dd$x, col = "red", lty = 2)
  box()

  # Density (top)
  par(mai = c(0, 0.8, 0.4, 0.1) + 0.02)
  par(fig = c(0, 0.8, 0.8, 1), new = TRUE)
  plot(
    0, 0, type = "n", axes = F,
    xlim = range(lhs_raw),
    ylim = c(0, 0.12), xlab = NA, ylab = NA
  )
  # Density from original dataset
  x1 <- getScaleSum(d_original, 2)
  dd <- density(x1$raw_2)
  lines(dd$x, dd$y, col = "blue")
  # Density from validation dataset
  x1 <- getScaleSum(d_validation, 2)
  dd <- density(x1$raw_2)
  lines(dd$x, dd$y, col = "red", lty = 2)
  box()

  dev.off()

}
