# Code: Sangdon Lim

rstudioapi::restartSession()

library(PROsetta)
library(mirt)
library(mvnfast)
library(devEMF)

d <- loadData(
  response  = "dat_dePHQ9_validation.csv",
  itemmap   = "imap_dePHQ9.csv",
  anchor    = "anchor_dePHQ9.csv",
  input_dir = "data"
)

# Figure 5

# The theta quadrature is seq(-4, 4, 0.05)

set.seed(1)
uni_link   <- runLinking(d, method = "FIXEDPAR")
uni_rsss   <- runRSSS(d, uni_link, min_score = c(1, 0, 1))
uni_tscore <- uni_rsss[[2]]$tscore

set.seed(1)
uni_link   <- runLinking(d, method = "FIXEDPAR")
uni_rsss   <- runRSSS(d, uni_link, min_score = c(1, 0, 1))
eqp_out    <- runEquateObserved(
  d,
  scale_from = 2, scale_to = 1,
  type_to = "theta", rsss = uni_rsss,
  degrees = list(6, 1),
  reps = 1000
)
eqp_out    <- eqp_out$concordance
eqp_tscore <- eqp_out$theta_1 * 10 + 50

set.seed(1)
cp_link    <- runLinking(d, method = "CP")
cp_rsss    <- runRSSS(d, cp_link, min_score = c(1, 0, 1))
cp_tscore  <- cp_rsss[[2]]$tscore_dim1
cp_corr    <- cp_link$mu_sigma$corr[1, 2]

for (img_format in c("eps", "emf", "svg")) {

  setEPS()
  if (img_format == "eps") postscript("figures/Figure 5.eps", width = 7, height = 7)
  if (img_format == "emf") emf(file = "figures/Figure 5.emf", width = 7, height = 7)
  if (img_format == "svg") svg(file = "figures/Figure 5.svg", width = 7, height = 7)

  lhs_range <- 0:27

  plot(0, 0,
    xlab = "Summed Score", ylab = "T-score", type = "n",
    xlim = range(lhs_range), ylim = c(30, 90))
  lines(lhs_range, uni_tscore, lty = 3, col = "black")      # UNI
  lines(lhs_range, eqp_tscore, lty = 2, col = "magenta")    # EQP
  lines(lhs_range, cp_tscore , lty = 1, col = "lime green") # CP

  legend("topleft",
    c("Unidimensional IRT", "Equipercentile",
      sprintf("Calibrated projection (r = %1.3f)", cp_corr)),
    lty = c(3, 2, 1), col = c("black", "magenta", "lime green"))
  box()

  dev.off()

}
