# Code: Sangdon Lim

library(PROsetta)
library(mirt)
library(mvnfast)
library(stringr)
library(devEMF)

d_original <- loadData(
  response  = "dat_dePHQ9_original.csv",
  itemmap   = "imap_dePHQ9.csv",
  anchor    = "anchor_dePHQ9.csv",
  input_dir = "data"
)
d_validation <- loadData(
  response  = "dat_dePHQ9_validation.csv",
  itemmap   = "imap_dePHQ9.csv",
  anchor    = "anchor_dePHQ9.csv",
  input_dir = "data"
)

lhs_scale <- 2
lhs_raw   <- 0:27
o <- data.frame(lhs_raw)

# Distribution

lhs_sum  <- getScaleSum(d_original, 2)
lhs_n    <- dim(lhs_sum)[1]
lhs_dist <- table(lhs_sum$raw_2) / lhs_n
o$dist_original <- round(lhs_dist * 100, 1)

lhs_sum  <- getScaleSum(d_validation, 2)
lhs_n    <- dim(lhs_sum)[1]
lhs_dist <- table(lhs_sum$raw_2) / lhs_n
o$dist_validation <- round(lhs_dist * 100, 1)

# Figure 4a

set.seed(1)
ipar_original   <- runLinking(d_original  , method = "FIXEDPAR")
set.seed(1)
ipar_validation <- runLinking(d_validation, method = "FIXEDPAR")

rsss_uni_original   <- runRSSS(d_original  , ipar_original  , min_score = 0)
rsss_uni_validation <- runRSSS(d_validation, ipar_validation, min_score = 0)

o$original_uni   <- rsss_uni_original[[lhs_scale]]$tscore
o$validation_uni <- rsss_uni_validation[[lhs_scale]]$tscore

# Figure 4b

set.seed(1)
ipar_original <- runLinking(d_original  , method = "FIXEDPAR")
rsss_original <- runRSSS(d_original, ipar_original)
set.seed(1)
ipar_validation <- runLinking(d_validation, method = "FIXEDPAR")
rsss_validation <- runRSSS(d_validation, ipar_validation)

set.seed(1)
eqp_original <- runEquateObserved(
  d_original,
  scale_from = 2, scale_to = 1,
  type_to = "theta", rsss = rsss_original,
  degrees = list(6, 1),
  reps = 1000
)
set.seed(1)
eqp_validation <- runEquateObserved(
  d_validation,
  scale_from = 2, scale_to = 1,
  type_to = "theta", rsss = rsss_validation,
  degrees = list(6, 1),
  reps = 1000
)

o$original_eqp   <- eqp_original$concordance$theta_1 * 10 + 50
o$validation_eqp <- eqp_validation$concordance$theta_1 * 10 + 50

eqp_original$concordance$theta_1_se_boot * 10
eqp_validation$concordance$theta_1_se_boot * 10

# Figure 4c

set.seed(1)
cp_original   <- runLinking(d_original  , method = "CP")
set.seed(1)
cp_validation <- runLinking(d_validation, method = "CP")

rsss_cp_original   <- runRSSS(d_original  , cp_original  , min_score = 0)
rsss_cp_validation <- runRSSS(d_validation, cp_validation, min_score = 0)

o$original_cp   <- rsss_cp_original[[lhs_scale]]$tscore_dim1
o$validation_cp <- rsss_cp_validation[[lhs_scale]]$tscore_dim1

o <- round(o, 1)

write.csv(o, "figures/Supplementary Table.csv", row.names = FALSE)
