# Code: Sangdon Lim

library(stringr)
library(devEMF)

fp    <- file.path("results")
f_all <- list.files(fp)
corr  <- seq(1.0, 0.6, -0.05)
out_all <- as.data.frame(matrix(NA, 0, 4))

for (r in corr) {

  tmp <- sprintf("out_%s_", r)
  idx <- str_detect(f_all, tmp)
  fs  <- f_all[idx]

  out <- as.data.frame(matrix(NA, length(fs), 4))

  for (i in 1:length(fs)) {

    d <- read.csv(file.path(fp, fs[i]))
    diff_uni  <- d$rhs_theta_uni  - d$rhs_theta
    diff_eqp  <- d$rhs_theta_eqp  - d$rhs_theta
    diff_cp   <- d$rhs_theta_cp   - d$rhs_theta
    rmse_uni  <- sqrt(mean((diff_uni )**2))
    rmse_eqp  <- sqrt(mean((diff_eqp )**2))
    rmse_cp   <- sqrt(mean((diff_cp  )**2))
    out[i, ] <- c(r, rmse_uni, rmse_eqp, rmse_cp)

  }

  out_all <- rbind(out_all, out)

}

out_avg <- aggregate(
  out_all, by = list(out_all[, 1]),
  function(x) sqrt(mean(x**2))
)[, -1]

colnames(out_avg) <- c("corr", "uni", "eqp", "cp")

idx <- order(out_avg$corr, decreasing = TRUE)
out_avg <- out_avg[idx, ]

# Perform RMSE prediction

RMSE_theta_2 <- out_avg$uni[1]
RMSE_theta_1 <- sqrt(1 - ((out_avg$corr ** 2) * (1 - (RMSE_theta_2 ** 2))))

out_avg$pred <- RMSE_theta_1

# Table 4

round(out_avg, 3)
