# Calibrated Projection with hypothetical correlation values

CP_hypothetical <- function(d, cor_value) {

  # Step 1. Perform 1D calibration on PROMIS data only, constraining item parameters to anchor values
  # The goal of this step is to obtain the latent mean and SD of the PROMIS dimension
  d_pro          <- d
  d_pro@response <- getResponse(d, scale_id = 1, person_id = TRUE)
  d_pro@itemmap  <- d_pro@itemmap[
    d_pro@itemmap$item_id %in% getItemNames(d_pro, scale_id = 1),
  ]

  set.seed(1)
  cp_calib_pro      <- runCalibration(d_pro, dimensions = 1, fixedpar = TRUE)
  cp_calib_pro_pars <- mirt::coef(cp_calib_pro, IRTpars = FALSE, simplify = TRUE)

  # Step 2. Perform 2D calibration, constraining PROMIS item parameters to anchor values
  # and also constraining latent means and variances
  par_layout  <- PROsetta:::getParLayout(d, dimensions = 2, bound_cov = FALSE)
  par_layout  <- PROsetta:::fixParLayout(par_layout, d)

  anchor_dim <- 1 # PROMIS dimension
  target_dim <- 2 # PHQ dimension

  # Constrain PROMIS dimension using 1D results
  idx_mean <- which(
    par_layout$class == "GroupPars" &
    par_layout$name == sprintf("MEAN_%s", anchor_dim)
  )
  par_layout[idx_mean, ]$value <- cp_calib_pro_pars$means
  par_layout[idx_mean, ]$est   <- FALSE

  idx_var <- which(
    par_layout$class == "GroupPars" &
    par_layout$name == sprintf("COV_%s%s", anchor_dim, anchor_dim)
  )
  par_layout[idx_var, ]$value <- cp_calib_pro_pars$cov
  par_layout[idx_var, ]$est   <- FALSE

  # Constrain PHQ dimension
  idx_mean <- which(
    par_layout$class == "GroupPars" &
      par_layout$name == sprintf("MEAN_%s", target_dim)
  )
  par_layout[idx_mean, ]$est <- FALSE
  idx_var <- which(
    par_layout$class == "GroupPars" &
      par_layout$name == sprintf("COV_%s%s", target_dim, target_dim)
  )
  par_layout[idx_var, ]$est  <- FALSE

  # Constrain PROMIS-PHQ covariance using hypothetical values
  idx_cov <- which(
  par_layout$class == "GroupPars" &
    par_layout$name == sprintf("COV_%s%s", target_dim, anchor_dim)
  )
  par_layout[idx_cov, ]$value <- cor_value * sqrt(cp_calib_pro_pars$cov)
  par_layout[idx_cov, ]$est   <- FALSE

  # Step 3. Fit a 2D model
  set.seed(1)
  model_specs <- PROsetta:::getModel(d, dimensions = 2, bound_cov = FALSE)
  cp_calib    <- mirt::mirt(getResponse(d), model_specs, itemtype = "graded", pars = par_layout)

  return(cp_calib)

}
